@@ -107,7 +107,7 @@ def verbnet(doc):
 	for name, ibeg, iend in matcher(doc):
 		arr = spacy.nlp.vocab[name].text.split(':') 
 		i = ibeg + int(arr[-1]) 
-		doc.user_data[f"verbnet-{i}"] = {"type":"verbnet", "start": ibeg, "end": iend, "lem":doc[i].lemma_,"chunk":arr[0].strip()}
+		doc.user_data[f"verbnet-{i}"] = {"type":"verbnet", "start": ibeg, "end": iend, "lem":doc[i].lemma_, "lempos":doc[i].lemma_ + "_" + doc[i].pos_, "chunk":arr[0].strip()}
 
 simple_sent		= lambda doc: len([t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT']) <= 0 
 complex_sent	= lambda doc: len([t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT']) > 0
@@ -129,7 +129,7 @@ def clause(doc):  # {'S.prep-0': {'type': 'S.prep', 'start': 0, 'end': 2, 'lem':
 		children = list(v.subtree)
 		start = children[0].i  	#end = children[-1].i 
 		type = "S." + v.dep_   # S.advcl ,  S.conj 
-		doc.user_data[f"{type}-{start}"] = {"type":type, "start": start, "end":children[-1].i + 1, "lem":v.lemma_,"chunk": " ".join([c.text for c in v.subtree])}
+		doc.user_data[f"{type}-{start}"] = {"type":type, "start": start, "end":children[-1].i + 1, "lem":v.lemma_,"lempos":v.lemma_ + "_" + v.pos_,"chunk": " ".join([c.text for c in v.subtree])}
 
 def attach(doc):
 	verbnet(doc)
