@@ -161,21 +161,28 @@ class ES(object):
 
 	def clear(self,idxname): self.es.delete_by_query(index=idxname, body={"query": {"match_all": {}}})
 	def dumpid(self, idxname): [print (doc['_id'] + "\t" + json.dumps(doc['_source']))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
-	def dump(self, idxname): [print (json.dumps(doc))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
+	def dumpraw(self, idxname): [print (json.dumps(doc))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
 	def keys(self, idxname): [print(resp['_id']) for resp in  helpers.scan(client=self.es, query={"query" : {"match_all" : {}}}, scroll= "10m", index= idxname , timeout="10m") ]
 	def hello(self): print (self.es)
 
-	def load(self, infile, idxname, batch=100000): 
-		''' python3 -m so load essaydm.json essaydm 
-		load id-source-file into index, 2022.4.2 '''
+	def dump(self, idxname): 
+		''' python -m so dump gzjc  > gzjc.esjson '''
+		for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname):
+			del doc["sort"]
+			del doc["_score"]
+			print (json.dumps(doc))  
+
+	def load(self, infile, idxname=None, batch=100000, refresh:bool=True): 
+		''' python3 -m so load gzjc.esjson '''
+		if not idxname : idxname = infile.split('.')[0]
 		print(">>started: " , infile, idxname, flush=True )
+		#if refresh: self.clear(idxname) 
 		actions=[]
 		for line in readline(infile): 
 			try:
-				arr = json.loads(line) 
-				#arr.update({'_op_type':'index', '_index':idxname,}) 
+				arr = json.loads(line)  #arr.update({'_op_type':'index', '_index':idxname,}) 
 				actions.append( {'_op_type':'index', '_index':idxname, '_id': arr.get('_id',None), '_source': arr.get('_source',{}) } )
-				if len(actions) > batch: 
+				if len(actions) >= batch: 
 					helpers.bulk(client=self.es,actions=actions, raise_on_error=False)
 					print ( actions[-1], flush=True)
 					actions = []
