@@ -1,9 +1,12 @@
 # 2022.5.20 cp from stream/uvirun.py  | uvicorn uviredis:app --host 0.0.0.0 --port 7379 --reload 
-import json,requests,hashlib,os,time,redis,fastapi, uvicorn , random,asyncio
-app			= fastapi.FastAPI() 
-rhost,rport,rdb	= os.getenv("rhost", "172.17.0.1"),int(os.getenv('rport', 6379)),int(os.getenv('rdb', 0))
+import json,requests,hashlib,os,time,redis,fastapi, uvicorn , random,asyncio, platform
+app				= fastapi.FastAPI() 
+rhost,rport,rdb	= os.getenv("rhost", "127.0.0.1" if "Windows" in platform.system() else "172.17.0.1"),int(os.getenv('rport', 6379)),int(os.getenv('rdb', 0))
 redis.r			= redis.Redis(host=rhost, port=rport, db=rdb, decode_responses=True) 
 
+@app.get('/redis/info')
+def redis_info(): return redis.r.info()
+
 @app.get('/redis/rg_pyexecute')
 def rg_pyexecute(cmd:str="GB().flatmap(lambda x: execute('hvals', x['key']) ).countby().run('rid-230537:tid-1:uid-*')", name:str = 'rg.eval'):
 	''' GB().map(lambda x: x['value']).flatmap(lambda x: x.split()).countby().run('sent:*')	'''
